@@ -1,11 +1,13 @@
 package WWW::Mailchimp;
-use Moose;
+use Moo;
 use LWP;
 use JSON;
 use URI;
 use PHP::HTTPBuildQuery qw(http_build_query);
+use MooX::Types::MooseLike::Base qw(Int InstanceOf Num Str);
+use Sub::Name;
 
-our $VERSION = '0.006_01';
+our $VERSION = '0.006_03';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -34,15 +36,13 @@ WWW::Mailchimp - Perl wrapper around the Mailchimp v1.3 API
 WWW::Mailchimp is a simple Perl wrapper around the Mailchimp API v1.3.
   
 It is as simple as creating a new WWW::Mailchimp object and calling ->method
-Each key/value pair becomes part of POST content, for example:
+Each key/value pair becomes part of a query string, for example:
 
   $mailchimp->listSubscribe( id => 1, email_address => 'foo@bar.com' );
 
-results in the query
+results in the query string
 
-  ?method=listSubscribe # GET URI
-  # POST CONTENT
-  &id=1&email_address=foo@bar.com
+  ?method=listSubscribe&id=1&email_address=foo@bar.com
   # apikey, output, etc are tacked on by default. This is also uri_escaped
 
 =head1 BUGS
@@ -74,21 +74,21 @@ the same terms as the Perl 5 programming language system itself.
 
 has api_version => (
   is => 'ro',
-  isa => 'Num',
+  isa => Num,
   lazy => 1,
-  default => 1.3,
+  default => sub { 1.3 },
 );
 
 has datacenter => (
   is => 'rw',
-  isa => 'Str',
+  isa => Str,
   lazy => 1,
-  default => 'us1',
+  default => sub { 'us1' },
 );
 
 has apikey => (
   is => 'ro',
-  isa => 'Str',
+  isa => Str,
   required => 1,
   trigger => sub {
     my ($self, $val) = @_;
@@ -99,42 +99,40 @@ has apikey => (
 
 has api_url => (
   is => 'rw',
-  isa => 'Str',
+  isa => Str,
   lazy => 1,
   default => sub { my $self = shift; return 'https://' . $self->datacenter . '.api.mailchimp.com/' . $self->api_version . '/'; },
 );
 
 has output_format => (
   is => 'rw',
-  isa => 'Str',
+  isa => Str,
   lazy => 1,
-  default => 'json',
+  default => sub { 'json' },
 );
 
 has ua => (
-  is => 'ro',
-  isa => 'LWP::UserAgent',
-  lazy => 1,
-  builder => '_build_lwp',
-  handles => [ qw(post) ],
+  is => 'lazy',
+  isa => InstanceOf['LWP::UserAgent'],
+  handles => [ qw(request) ],
 );
 
 has timeout => (
   is => 'rw',
-  isa => 'Int',
+  isa => Int,
   lazy => 1,
-  default => 5,
+  default => sub { 5 },
 );
 
-has 'json' => (
-    is => 'ro',
-    isa => 'JSON',
-    lazy_build => 1,
+has json => (
+  is => 'ro',
+  isa => InstanceOf['JSON'],
+  is => 'lazy',
 );
 
-sub _build_lwp {
+sub _build_ua {
   my $self = shift;
-  my $ua = LWP::UserAgent->new( timeout => $self->timeout, agent => __PACKAGE__ . ' ' . $VERSION, ssl_opts => { verify_hostname => 0 } );
+  my $ua = LWP::UserAgent->new( timeout => $self->timeout, agent => __PACKAGE__ . ' ' . $VERSION, ssl_opts => { verify_hostname => 0, SSL_verify_mode => 0x00 } );
 }
 
 sub _build_json { JSON->new->allow_nonref }
@@ -154,7 +152,13 @@ sub _build_query_args {
     }
   }
 
-  return %args;
+  my $uri = URI->new( $self->api_url );
+  $args{apikey} = $self->apikey;
+  $args{output} = $self->output_format;
+  delete $args{$_} for qw(json ua);
+
+  $uri->query( http_build_query( \%args ) );
+  return $uri;
 }
 
 sub _request {
@@ -162,13 +166,9 @@ sub _request {
   my $method = shift;
   my %args = ref($_[0]) ? %{$_[0]} : @_;
 
-  %args = $self->_build_query_args(apikey => $self->apikey, output => $self->output_format, %args);
+  my $uri = $self->_build_query_args(method => $method, %args);
 
-  my $uri = URI->new( $self->api_url );
-  $uri->query_form_hash(method => $method); # method must be in GET
-
- # use POST to fix '414 Request-URI Too Large'
-  my $response = $self->post( $uri->canonical, \%args );
+  my $response = $self->request( HTTP::Request->new( GET => $uri->canonical ) );
   return $response->is_success ? $self->json->decode($response->content) : $response->status_line;
 }
 
@@ -269,8 +269,11 @@ my @api_methods = qw(
   templates
 );
 
-for my $method (@api_methods) {
-  __PACKAGE__->meta->add_method( $method => sub { shift->_request($method, @_) } );
+sub BUILD {
+  no strict 'refs';
+  for my $method (@api_methods) {
+    *{$method} = subname $method => sub { shift->_request($method, @_) };
+  }
 }
 
 1;
